@@ -5,6 +5,7 @@
 
 use bsp::hal;
 use feather_m4 as bsp;
+
 #[cfg(not(feature = "use_semihosting"))]
 use panic_halt as _;
 #[cfg(feature = "use_semihosting")]
@@ -30,8 +31,8 @@ fn main() -> ! {
     );
     // We will use the red led and a delay in this simplest possible
     // demonstration of the random number generator.
-    let mut pins = bsp::Pins::new(peripherals.PORT);
-    let mut red_led = pins.d13.into_open_drain_output(&mut pins.port);
+    let pins = bsp::Pins::new(peripherals.PORT);
+    let mut red_led = pins.d13.into_push_pull_output();
     let mut delay = hal::delay::Delay::new(core.SYST, &mut clocks);
 
     // Create a struct as a representation of the random number generator peripheral
