@@ -16,7 +16,7 @@ use panic_halt as _;
 #[cfg(feature = "use_semihosting")]
 use panic_semihosting as _;
 
-use bsp::entry;
+use bsp::{entry, periph_alias, pin_alias};
 use hal::clock::GenericClockController;
 use hal::delay::Delay;
 use hal::pac::gclk::genctrl::SRC_A;
@@ -40,16 +40,20 @@ fn main() -> ! {
 
     let pins = bsp::Pins::new(peripherals.PORT);
     let mut delay = Delay::new(core.SYST, &mut clocks);
-    let mut red_led = pins.d13.into_push_pull_output();
+    let mut red_led: bsp::RedLed = pin_alias!(pins.red_led).into();
+
+    // Take RX and TX pins
+    let uart_rx = pin_alias!(pins.uart_rx);
+    let uart_tx = pin_alias!(pins.uart_tx);
+    let uart_sercom = periph_alias!(peripherals.uart_sercom);
 
-    let (tx, rx) = (pins.d1, pins.d0);
     let mut uart = bsp::uart(
         &mut clocks,
         Hertz(19200),
-        peripherals.SERCOM5,
+        uart_sercom,
         &mut peripherals.MCLK,
-        rx,
-        tx,
+        uart_rx,
+        uart_tx,
     );
 
     // Write out a message on start up
